@@ -13,14 +13,14 @@ A container for functions for the ack program.
 
 =head1 VERSION
 
-Version 2.999_07
+Version 2.999_08
 
 =cut
 
 our $VERSION;
 our $COPYRIGHT;
 BEGIN {
-    $VERSION = '2.999_07';
+    $VERSION = '2.999_08';
     $COPYRIGHT = 'Copyright 2005-2019 Andy Lester.';
 }
 our $STANDALONE = 0;
@@ -214,21 +214,6 @@ Dumps the help page to the user.
 =cut
 
 sub show_help {
-    my $manual_options;
-    if ( $App::Ack::STANDALONE ) {
-        $manual_options = <<'END';
-  --man                         Print the manual, FAQ and cookbook
-END
-    }
-    else {
-        $manual_options = <<'END';
-  --man                         Print the manual
-  --faq                         Print the frequently asked questions
-  --cookbook                    Print a list of tips and tricks for using ack
-END
-    }
-    chomp $manual_options;
-
     App::Ack::print( <<"END_OF_HELP" );
 Usage: ack [OPTION]... PATTERN [FILES OR DIRECTORIES]
 
@@ -361,7 +346,7 @@ Miscellaneous:
   --[no]filter                  Force ack to treat standard input as a pipe
                                 (--filter) or tty (--nofilter)
   --help                        This help
-$manual_options
+  --man                         Print the manual.
   --help-types                  Display all known types, and how they're defined.
   --help-colors                 Show a list of possible color combinations.
   --help-rgb-colors             Show a list of advanced RGB colors.
@@ -570,26 +555,12 @@ HERE
 }
 
 
-sub show_docs {
-    my $section = shift;
-
-    my $input;
-    if ( $App::Ack::STANDALONE ) {
-        # Standalone doesn't have the modules split out, so dump the entire file.
-        $input = $App::Ack::ORIGINAL_PROGRAM_NAME;
-    }
-    else {
-        my $module = "App::Ack::Docs::$section";
-        eval "require $module" or App::Ack::die( "Can't load $module" );
-        $input = $INC{ "App/Ack/Docs/$section.pm" };
-    }
-
+sub show_man {
     require Pod::Usage;
     Pod::Usage::pod2usage({
-        -input     => $input,
-        -verbose   => 2,
-        -exitval   => 0,
-        -noperldoc => 1, # Use Pod::Text.
+        -input   => $App::Ack::ORIGINAL_PROGRAM_NAME,
+        -verbose => 2,
+        -exitval => 0,
     });
 
     return;
